@@ -3,9 +3,9 @@ package jdk.internal.jshell.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "20.0.1+9" },
-            { "jdk", "20.0.1" },
-            { "release", "20.0.1" },
+            { "full", "21.0.1+12-LTS" },
+            { "jdk", "21.0.1" },
+            { "release", "21.0.1" },
         };
     }
 }
